@@ -10,7 +10,7 @@ use strict;
 
 use Test::Smoke;
 use vars qw($VERSION);
-$VERSION = Test::Smoke->VERSION;
+$VERSION = Test::Smoke->VERSION; # $Id: mkovz.pl 155 2003-06-06 15:42:50Z abeltje $
 
 use File::Spec;
 use Cwd;
@@ -219,11 +219,12 @@ for (<OUT>) {
 $Config{ccvers}	||= $Config{gccversion} || $Config{ccversion};
 require Sys::Hostname;
 my $this_host = Sys::Hostname::hostname() || "nohost";
+my $this_pver = $^V ? sprintf "%vd", $^V : $];
 
 print <<EOH;
 Automated smoke report for $Config{version} patch $rpt{patch} on $Config{osname} - $Config{osvers} ($Config{archname})
 ($this_host) using $Config{cc} version $Config{ccvers}
-Report generated by Test::Smoke v$VERSION
+Report generated by Test::Smoke v$VERSION (perl $this_pver)
 
 O = OK  F = Failure(s), extended report at the bottom
 ? = still running or test results not (yet) available
